<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Steps definitions related to Repository s3bucket.
 *
 * @package    repository_s3bucket
 * @copyright  2019 Renaat Debleu (www.eWallah.net)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

// NOTE: no MOODLE_INTERNAL test here, this file may be required by behat before including /config.php.

require_once(__DIR__ . '/../../../../lib/behat/behat_base.php');

/**
 * Repository s3bucket related steps definitions.
 *
 * @package    repository_s3bucket
 * @copyright  2019 Renaat Debleu (www.eWallah.net)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class behat_repository_s3bucket extends behat_base {

    /**
     * Enable s3 bucket.
     *
     * @Given /^I enable repository "(?P<repository_string>(?:[^"]|\\")*)"$/
     * @param string $repository
     * @throws dml_exception
     */
    public function i_enable_repository($repository) {
        global $DB;
        if (!$DB->record_exists('repository', ['type' => $repository])) {
            $DB->insert_record('repository', (object) ['type' => $repository, 'visible' => 1]);
        }
    }
}
